function freq_resp = calc_analytical_freq_response(sample_points, input)
% sample_points - vector of sample points for which to calculate frequency
%                 response
% input - 6x1 vector, with all elements, except for one, zero.
%       Defines which frequency responses to calculate, output/(element in:)
%       [Vi(L) Va(L) Vp(L) Pi(0) Pa(0) Pp(0)]'
    sys = gen_transmission_line_freq_dependant_parameters(sample_points);
    
    L = sys.L;
    
    Zi = sys.Zi;
    Xi = sys.Xi;
    Yi = sys.Yi;
    Yix = sys.Yix;
    
    Za = sys.Za;
    Xa = sys.Xa;
    Ya = sys.Ya;
    Yax = sys.Yax;
    
    Zp = sys.Zp;
    Yp = sys.Yp;    
    fis = sys.fis;
    fas = sys.fas;    
    
    Vi_0 = zeros(size(sample_points));
    Pi_L = zeros(size(sample_points));
    Va_0 = zeros(size(sample_points));
    Pa_L = zeros(size(sample_points));
    Vp_0 = zeros(size(sample_points));
    Pp_L = zeros(size(sample_points));
    
    for w = 1:length(sample_points)
        A = [0,      -Yi(w),  0,      -Yix(w), 0,           0;
             -Zi(w), 0,       0,      0,       Zi(w)*Xi(w), 0;
             0,      -Yax(w), 0,      -Ya(w),  0,           0;
             0,      0,       -Za(w), 0,       Za(w)*Xa(w), 0;
             0       fis(w),  0,      -fas(w), 0,           -Yp(w);
             0,      0,       0,      0,       -Zp(w),      0];
            
        [V,lambda] = eig(A);
        
        Lambda_0 = diag(exp(diag(lambda*0)));
        Lambda_L = diag(exp(diag(lambda*L)));
        
        y_bar_0 = V*Lambda_0;
        y_bar_L = V*Lambda_L;
        
        % Boundary conditions
        D = [y_bar_L(1,:);
             y_bar_L(3,:);
             y_bar_L(5,:);
             y_bar_0(2,:);
             y_bar_0(4,:);
             y_bar_0(6,:)];
        
        % Constant of integration
        C = D\input;
        
        Vi_0(w) = y_bar_0(1,:)*C;
        Pi_L(w) = y_bar_L(2,:)*C;
        Va_0(w) = y_bar_0(3,:)*C;
        Pa_L(w) = y_bar_L(4,:)*C;
        Vp_0(w) = y_bar_0(5,:)*C;
        Pp_L(w) = y_bar_L(6,:)*C;
    end
    % Stacking output
    freq_resp = [Vi_0, Va_0, Vp_0, Pi_L, Pa_L, Pp_L];
end

