clear all
close all
clc

%% Parameters
well = gen_well_parameters;
num_modes = 32;
num_freqs = 500;
sigma = 0.0;
gamma_fun = @(alpha,sigma) (sigma+2*alpha);
r = 3*num_modes;

dw = 0.0001;
w = (dw:dw:5)';
s = 1j*w;

gammaV0P0   = zeros(9,1);
alphaV0P0   = zeros(9,1);
numV0P0     = zeros(9,r);
denV0P0     = zeros(9,r+1);
HrV0P0      = zeros(length(s),9);

gammaPLVL   = zeros(9,1);
alphaPLVL   = zeros(9,1);
numPLVL     = zeros(9,r);
denPLVL     = zeros(9,r+1);
HrPLVL      = zeros(length(s),9);

c = 1;
for dim2 = 1:3
    for dim1 = 1:3
        [gammaV0P0(c), alphaV0P0(c)] = find_alpha_and_gamma(sigma,@sample_ritz_V0P0_test,num_modes,num_freqs,gamma_fun,dim1,dim2);
        [numV0P0(c,:), denV0P0(c,:)] = gen_rational_tf(num_freqs,alphaV0P0(c), gammaV0P0(c),r,@sample_ritz_V0P0_test,num_modes,dim1,dim2);
        HrV0P0(:,c) = calc_rational_freq_response(numV0P0(c,:),denV0P0(c,:),s);
        
        [gammaPLVL(c), alphaPLVL(c)] = find_alpha_and_gamma(sigma,@sample_ritz_PLtoVL,num_modes,num_freqs,gamma_fun,dim1,dim2);
        [numPLVL(c,:), denPLVL(c,:)] = gen_rational_tf(num_freqs,alphaPLVL(c), gammaPLVL(c),r,@sample_ritz_PLtoVL,num_modes,dim1,dim2);
        HrPLVL(:,c) = calc_rational_freq_response(numPLVL(c,:),denPLVL(c,:),s);
        c = c+1;
    end
end
%% Approximating rational tranfer functions
sys = gen_transmission_line_freq_dependant_parameters(s);
Y = sys.Y;    % Rational elements!
HrV0Pi0 = zeros(length(w),3);
HrV0Pa0 = zeros(length(w),3);
HrV0Pp0 = zeros(length(w),3);

for n = 1:length(w)
    tempY = Y{n};
    tempH = [HrV0P0(n,1),HrV0P0(n,4),HrV0P0(n,7);
             HrV0P0(n,2),HrV0P0(n,5),HrV0P0(n,8);
             HrV0P0(n,3),HrV0P0(n,6),HrV0P0(n,9)];
    tempV0P0 = tempH*tempY;
    HrV0P0(n,:) = [tempV0P0(1,1),tempV0P0(2,1),tempV0P0(3,1),tempV0P0(1,2),tempV0P0(2,2),tempV0P0(3,2),tempV0P0(1,3),tempV0P0(2,3),tempV0P0(3,3)];
end


%% Calculating analytical solution
HiV0ViL = calc_analytical_freq_response(s,[1 0 0 0 0 0]');
HiV0VaL = calc_analytical_freq_response(s,[0 1 0 0 0 0]');
HiV0VpL = calc_analytical_freq_response(s,[0 0 1 0 0 0]');
HiPLPi0 = calc_analytical_freq_response(s,[0 0 0 1 0 0]');
HiPLPa0 = calc_analytical_freq_response(s,[0 0 0 0 1 0]');
HiPLPp0 = calc_analytical_freq_response(s,[0 0 0 0 0 1]');

HiV0VL = [HiV0ViL(:,1:3),HiV0VaL(:,1:3),HiV0VpL(:,1:3)];
HiV0P0 = [HiPLPi0(:,1:3),HiPLPa0(:,1:3),HiPLPp0(:,1:3)];
HiPLVL = [HiV0ViL(:,4:6),HiV0VaL(:,4:6),HiV0VpL(:,4:6)];
HiPLP0 = [HiPLPi0(:,4:6),HiPLPa0(:,4:6),HiPLPp0(:,4:6)];

%% Plotting 
% Plot config
width = 5.5;     % Width in inches
height = 2;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 9;      % Fontsize
lw = 2;      % LineWidth
msz = 8;       % MarkerSize
set(0,'defaultLineLineWidth',lw);
set(0,'defaultLineMarkerSize',msz); 
set(0,'defaultLineLineWidth',lw);  
set(0,'defaultLineMarkerSize',msz);
set(0,'defaulttextfontsize',fsz);
set(0,'defaultAxesFontSize',fsz);
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
close all
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);
set(0,'defaulttextinterpreter','latex');

% Defening save names

fnames = {'V0iVLirat_3xmodes_o0', 'V0aVLirat_3xmodes_o0', 'V0pVLirat_3xmodes_o0', ...
          'V0iVLarat_3xmodes_o0', 'V0aVLarat_3xmodes_o0', 'V0pVLarat_3xmodes_o0', ...
          'V0iVLprat_3xmodes_o0', 'V0aVLprat_3xmodes_o0', 'V0pVLprat_3xmodes_o0', ...
          'V0iP0irat_3xmodes_o0', 'V0aP0irat_3xmodes_o0', 'V0pP0irat_3xmodes_o0', ...
          'V0iP0arat_3xmodes_o0', 'V0aP0arat_3xmodes_o0', 'V0pP0arat_3xmodes_o0', ...
          'V0iP0prat_3xmodes_o0', 'V0aP0prat_3xmodes_o0', 'V0pP0prat_3xmodes_o0', ...
          'PLiVLirat_3xmodes_o0', 'PLaVLirat_3xmodes_o0', 'PLpVLirat_3xmodes_o0', ...
          'PLiVLarat_3xmodes_o0', 'PLaVLarat_3xmodes_o0', 'PLpVLarat_3xmodes_o0', ...
          'PLiVLprat_3xmodes_o0', 'PLaVLprat_3xmodes_o0', 'PLpVLprat_3xmodes_o0', ...
          'PLiP0irat_3xmodes_o0', 'PLaP0irat_3xmodes_o0', 'PLpP0irat_3xmodes_o0', ...
          'PLiP0arat_3xmodes_o0', 'PLaP0arat_3xmodes_o0', 'PLpP0arat_3xmodes_o0', ...
          'PLiP0prat_3xmodes_o0', 'PLaP0prat_3xmodes_o0', 'PLpP0prat_3xmodes_o0'};
% Defining save path
path = 'C:\Users\andedah\Dropbox\master\thesis\fig\appendix\rational\';
for i = 1:36
    fnames{i} = [path,fnames{i}];
end

w_end = 2;
for i = 1:9
    h = figure(i);
    subplot(121),plot(w,abs(HiV0VL(:,i))  ,w,abs(HrV0VL(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
    subplot(122),plot(w,phase(HiV0VL(:,i)),w,phase(HrV0VL(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Phase')
    legend('PDE','Rational','location','best')
    print(h,'-dpng',fnames{i},'-r600')
    
    h = figure(9+i);
    subplot(121),plot(w,abs(HiV0P0(:,i))  ,w,abs(HrV0P0(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
    subplot(122),plot(w,phase(HiV0P0(:,i)),w,phase(HrV0P0(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Phase')
    legend('PDE','Rational','location','best')
    print(h,'-dpng',fnames{9+i},'-r600')
    
    h = figure(18+i);
    subplot(121),plot(w,abs(HiPLVL(:,i))  ,w,abs(HrPLVL(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
    subplot(122),plot(w,phase(HiPLVL(:,i)),w,phase(HrPLVL(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Phase')
    legend('PDE','Rational','location','best')
    print(h,'-dpng',fnames{18+i},'-r600')
    
    h = figure(27+i);
    subplot(121),plot(w,abs(HiPLP0(:,i))  ,w,abs(HrPLP0(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
    subplot(122),plot(w,phase(HiPLP0(:,i)),w,phase(HrPLP0(:,i)),'r--')
    xlim([dw,w_end]), xlabel('$\omega$[rad/s]'),ylabel('Phase')
    legend('PDE','Rational','location','best')
    print(h,'-dpng',fnames{27+i},'-r600')
end






