clear all
close all
clc

%% Parameters
well = gen_well_parameters;
num_modes = 32;
num_freqs = 1500;
sigma = [0,0.007,0.01,0.2];
gamma_fun = @(alpha,sigma) (sigma+2*alpha);
r = 2*num_modes;

dw = 0.0001;
w = (dw:dw:5)';
s = 1j*w;

% Finding alpha and gamma
HrPLVL      = zeros(length(s),length(num_freqs));

dim1 = 3;
dim2 = 1;

numPLVL = zeros(length(sigma),r);
denPLVL = zeros(length(sigma),r+1);

for k = 1:length(sigma)
    [gammaPLVL, alphaPLVL] = find_alpha_and_gamma(sigma(k),@sample_ritz_PLtoVL,num_modes,num_freqs,gamma_fun,dim1,dim2);
    [numPLVL(k,:), denPLVL(k,:)] = gen_rational_tf(num_freqs,alphaPLVL, gammaPLVL,r,@sample_ritz_PLtoVL,num_modes,dim1,dim2);
    HrPLVL(:,k) = calc_rational_freq_response(numPLVL(k,:),denPLVL(k,:),s);
end

HiViL = calc_analytical_freq_response(s,[1 0 0 0 0 0]');

%% Plotting 
% Plot config
width = 5.5;     % Width in inches
height = 7;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 9;      % Fontsize
lw = 2;      % LineWidth
msz = 8;       % MarkerSize
set(0,'defaultLineLineWidth',lw);
set(0,'defaultLineMarkerSize',msz); 
set(0,'defaultLineLineWidth',lw);  
set(0,'defaultLineMarkerSize',msz);
set(0,'defaulttextfontsize',fsz);
set(0,'defaultAxesFontSize',fsz);
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
close all
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);
set(0,'defaulttextinterpreter','latex');



path = 'C:\Users\andedah\Dropbox\master\thesis\fig\';
for k = 1:length(sigma)
    h1 = figure(1);
    subplot(length(sigma),1,k),plot(w,(abs(HiViL(:,6))-abs(HrPLVL(:,k)))./abs(HiViL(:,6))*100)
    xlim([dw,w(end)]), ylim([-100,100])
    xlabel('$\omega$[rad/s]'),ylabel('Error')
    title(['Amplitude Error in \%, $P_p$ $(L)/V_i$ $(L)$, $\sigma=$',num2str(sigma(k))])
    
    h2 = figure(2);
    subplot(length(sigma),1,k),plot(w,angle(HiViL(:,6)),w,angle(HrPLVL(:,k)),'r--')
    xlim([dw,w(end)]), xlabel('$\omega$[rad/s]'),ylabel('Phase')
    title(['$P_p$ $(L)/V_i$ $(L)$, $\sigma=$',num2str(sigma(k))])
    legend('PDE','Rational')
    
    h3 = figure(3);
    subplot(length(sigma),1,k),plot(zero(tf(numPLVL(k,:),denPLVL(k,:))),'or')
    hold on, plot(pole(tf(numPLVL(k,:),denPLVL(k,:))),'x')
    xlabel('Re'),ylabel('Im')
    title(['Poles and zeros of $P_p$ $(L)/V_i$ $(L)$, $\sigma=$',num2str(sigma(k))])
    legend('Zeros','Poles','location','best')
end


print(h1,'-dpng',[path,'PpLViL_pde_vs_rat_do_amp'],'-r600')
print(h2,'-dpng',[path,'PpLViL_pde_vs_rat_do_phase'],'-r600')
print(h3,'-dpng',[path,'PpLViL_pde_vs_rat_do_pz'],'-r600')


























