function trans_params  = gen_transmission_line_freq_dependant_parameters(sample_points)
% omega - frequency vector, for evaluation of frequency dependent
%   parameters
    well = gen_well_parameters;
    
    A_a = well.A_a;
    A_i = well.A_i;
    
    r_0 = well.r_0;
    r_1 = well.r_1;
    r_2 = well.r_2;
    
    L = well.L;
    
    beta_i = well.beta_i;
    beta_a = well.beta_a;
    
    A_i_pa = well.A_i_pa;
    A_a_pi = well.A_a_pi;
    
    rho = well.rho;
    rho_p = well.rho_p;
    
    E = well.E;
    
    nu = well.nu;
    
    k_p = well.k_p;
    
    f_i = well.f_i;
    f_a = well.f_a;
    
    %% Generating transmission line frequency dependent parameters
    s = sample_points;
    xi = 1j*sqrt(s/nu);
    
    H01_r0 = besselh(0,1,xi*r_0);           H02_r0 = besselh(0,2,xi*r_0);
    H01_r1 = besselh(0,1,xi*r_1);           H02_r1 = besselh(0,2,xi*r_1);
    H01_r2 = besselh(0,1,xi*r_2);           H02_r2 = besselh(0,2,xi*r_2);
    H11_r0 = besselh(1,1,xi*r_0);           H12_r0 = besselh(1,2,xi*r_0);
    H11_r1 = besselh(1,1,xi*r_1);           H12_r1 = besselh(1,2,xi*r_1);
    H11_r2 = besselh(1,1,xi*r_2);           H12_r2 = besselh(1,2,xi*r_2);

    Ii_1 = H11_r0*r_0./xi;                  
    Ii_2 = H12_r0*r_0./xi;
    Ia_1 = (H11_r2*r_2 - H11_r1*r_1)./xi;   
    Ia_2 = (H12_r2*r_2 - H12_r1*r_1)./xi;

    W = H01_r2.*H02_r1 - H01_r1.*H02_r2;
    C = 1./(H01_r0 + H02_r0);

    D1 = -(H02_r2 - H02_r1)./W;             
    D2 =  (H01_r2 - H01_r1)./W;
    E1 = -H02_r2./W;                        
    E2 =  H01_r2./W;


    % System vectors
    Zi = rho*s./(1-C.*(Ii_1+Ii_2)*2*pi/A_i);
    Yi = s./beta_i;
    Xi = 2*pi*C.*(Ii_1+Ii_2)/A_i;
    Yix = s.*A_i_pa;

    Za = rho*s./(1-(D1.*Ia_1+D2.*Ia_2)*2*pi/A_a);
    Ya = s./beta_a;
    Xa = 2*pi*(E1.*Ia_1+E2.*Ia_2)/A_a;
    Yax = s.*A_a_pi;

    Zp = rho_p.*s+k_p;
    Yp = s./E;
    
    Z = cell(size(s));
    Y = cell(size(s));
    Gamma = cell(size(s));
    for n = 1:length(s)
        Z{n} = [-Zi(n)   0         Zi(n)*Xi(n);
                 0      -Za(n)     Za(n)*Xa(n);
                 0       0        -Zp(n)];    
        Y{n} = [-Yi(n)    -Yix(n)     0;
                -Yax(n)   -Ya(n)      0;
                 f_i*s(n) -f_a*s(n)  -Yp(n)];
        Gamma{n} = Y{n}*Z{n};
    end
    trans_params.Z = Z;
    trans_params.Y = Y;
    trans_params.Gamma = Gamma;
    trans_params.L = L;
    
    trans_params.Zi = Zi;
    trans_params.Yi = Yi;
    trans_params.Xi = Xi;
    trans_params.Yix = Yix;
    
    trans_params.Za = Za;
    trans_params.Ya = Ya;
    trans_params.Xa = Xa;
    trans_params.Yax = Yax;
    
    trans_params.Zp = Zp;
    trans_params.Yp = Yp;
    trans_params.fis = f_i*s;
    trans_params.fas = f_a*s;
        
end

