function well_params = gen_well_parameters
    % Well cross sectional areas
    well_params.    A_a  = 0.0274;      % Annulus cross sectional area              - [m^2]
    well_params.    A_i  = 0.0118;      % Pipe cross sectional flow area            - [m^2]
    well_params.    A_p  = 0.003;       % Pipe cross sectional metal area           - [m^2]
    well_params.    Abh  = 0.0316;      % Bottom hole cross sectional area          - [m^2]
    
    % Pipe and annulus radius:
    r_0 = sqrt(well_params.A_i/pi);
    r_1 = sqrt((well_params.A_i+well_params.A_p)/pi);
    r_2 = sqrt((well_params.A_i+well_params.A_p+well_params.A_a)/pi);
                    
    well_params.    r_0 = r_0;                      % Inner pipe radius             - [m]
    well_params.    r_1 = r_1;                      % Outer pipe radius             - [m]
    well_params.    r_2 = r_2;                      % Annulus radius                - [m]
    
    % Length of pipe:                                        
    well_params.    L = 5000;               %                                       - [m]
    
    % Bulk modulus:
    well_params.    beta_i = 1.84e9;        % Pipe mud effective bulk modulus       - [Pa]
    well_params.    beta_a = 1.60e9;        % Annululs mud effective bulk modulus   - [Pa]
    well_params.    beta   = 2.2e9;         % Mud bulk modulus                      - [Pa]
    
    % Area change coefficients:
    well_params.    A_i_pa = -9.67e-11;     % Area change in pipe                   - [1/Pa]
    well_params.    A_a_pi = -4.18e-11;     % Area change in annulus                - [1/Pa]
    
    % Densities:
    well_params.    rho   = 1420;           % Mud density                           - [kg/m^3]
    well_params.    rho_p = 9000;           % Pipe density                          - [kg/m^3]
    
    % Young's modulus: 
    well_params.    E = 206.8e9;            % Young's modulus for pipe              - [Pa]
    well_params.    E_f = 30e9;             % ???????????????????????
    
    % Kinematic viscosity:
    well_params.    nu = 30e-6;             %                                       - [m^2/s]
    
    % Dampning coefficients:
    well_params.    k_p = 0.095;            % Pipe dampning coefficient             - [1/s]
    well_params.    K   = 5424;             % BHA dampning coefficient              - [Nsm]
    
    % Hoop strain coefficients: 
    well_params.    f_i = 1.45e-12;         % Hoop strain from pipe                 - [1/Pa]
    well_params.    f_a = 1.45e-12;         % Hoop strain from annulus              - [1/Pa]
    
    % BHA mass
    well_params.    M_bha = 400;            %                                       - [kg]
end