clear all
close all
clc

%% Parameters
% Generating well paramterers
well = gen_well_parameters;
% Simulation depth (height from bottom)
depth = 0;
% Number of modes in Ritz approximation
num_modes = [2,4,16];
% Laplace operator vector
dw = 0.00005;
w = (dw:dw:5)';
s = 1j*w;

%% Calculating analytical frequency solution
HiViL = calc_analytical_freq_response(s,[1 0 0 0 0 0]');
HiVaL = calc_analytical_freq_response(s,[0 1 0 0 0 0]');
HiVpL = calc_analytical_freq_response(s,[0 0 1 0 0 0]');
HiPi0 = calc_analytical_freq_response(s,[0 0 0 1 0 0]');
HiPa0 = calc_analytical_freq_response(s,[0 0 0 0 1 0]');
HiPp0 = calc_analytical_freq_response(s,[0 0 0 0 0 1]');
HiV0VL_plot = [HiViL(:,1:3),HiVaL(:,1:3),HiVpL(:,1:3)];
HiV0P0_plot = [HiPi0(:,1:3),HiPa0(:,1:3),HiPp0(:,1:3)];
HiPLVL_plot = [HiViL(:,4:6),HiVaL(:,4:6),HiVpL(:,4:6)];
HiPLP0_plot = [HiPi0(:,4:6),HiPa0(:,4:6),HiPp0(:,4:6)];
%% Calculating irrational Ritz
HritzV0toVL = cell(size(num_modes));
HritzV0toP0 = cell(size(num_modes));
HritzPLtoVL = cell(size(num_modes));
HritzPLtoP0 = cell(size(num_modes));
for m = 1:length(num_modes)
    HritzV0toVL{m} = sample_ritz_V0toVL(s,num_modes(m),depth);
    HritzV0toP0{m} = sample_ritz_V0toP0(s,num_modes(m),depth);
    HritzPLtoVL{m} = sample_ritz_PLtoVL(s,num_modes(m),depth);
    HritzPLtoP0{m} = sample_ritz_PLtoP0(s,num_modes(m),depth);
end
%% Plotting
% Amplitude and angle for different modes, V0/VL
plot1_V0VL_anal = HiV0VL_plot(:,1);
plot1_V0VL_ritz = zeros(length(w),length(num_modes));
for m = 1:length(num_modes)
    temp = HritzV0toVL{m};
    plot1_V0VL_ritz(:,m) = temp(:,1);
end

% Plot configure
width = 5.5;     % Width in inches
height = 3.45;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 6;      % Fontsize
lw = 2;      % LineWidth
msz = 8;       % MarkerSize

% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaulttextfontsize',fsz);
set(0,'defaultAxesFontSize',fsz);

% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);

% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize');
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

close all

set(0,'defaulttextinterpreter','latex');


h1 = figure;
subplot(211), plot(w,abs(plot1_V0VL_anal),w,abs(plot1_V0VL_ritz(:,1)),'r--')
xlim([w(1),w(end)])
title('Frequency response, 2 modes, $\bar{V}_i$ $(0)/\bar{V}_i$ $(L)$')
xlabel('$\omega [$rad$/$s$]$'), ylabel('Amplitude')
legend('PDE','Ritz')
subplot(212), plot(w,angle(plot1_V0VL_anal),w,angle(plot1_V0VL_ritz(:,1)),'r--')
xlim([w(1),w(end)])
xlabel('$\omega$ [rad/s]'), ylabel('angle')
print(h1,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0VL2modes','-r600')


h2 = figure;
subplot(211), plot(w,abs(plot1_V0VL_anal),w,abs(plot1_V0VL_ritz(:,2)),'r--')
xlim([w(1),w(end)])
title('Frequency response, 4 modes, $\bar{V}_i$ $(0)/\bar{V}_i$ $(L)$'), xlabel('$\omega [$rad$/$s$]$'), ylabel('Amplitude')
legend('PDE','Ritz')
subplot(212), plot(w,angle(plot1_V0VL_anal),w,angle(plot1_V0VL_ritz(:,2)),'r--')
xlim([w(1),w(end)])
xlabel('$\omega [$rad$/$s$]$'), ylabel('angle')
print(h2,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0VL4modes','-r600')

h3 = figure;
subplot(211), plot(w,abs(plot1_V0VL_anal),w,abs(plot1_V0VL_ritz(:,3)),'r--')
xlim([w(1),w(end)])
title('Frequency response, 16 modes, $\bar{V}_i$ $(0)/\bar{V}_i$ $(L)$'), xlabel('$\omega [$rad$/$s$]$'), ylabel('Amplitude')
legend('PDE','Ritz')
subplot(212), plot(w,angle(plot1_V0VL_anal),w,angle(plot1_V0VL_ritz(:,3)),'r--')
xlim([w(1),w(end)])
xlabel('$\omega [$rad$/$s$]$'), ylabel('angle')
print(h3,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0VL16modes','-r600')

close all

%% Plotting appendix Ritz 16 modes vs analytical
width = 5.5;     % Width in inches
height = 2;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 9;      % Fontsize
lw = 2;      % LineWidth
msz = 8;       % MarkerSize

defsize = get(gcf, 'PaperSize');
close all
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

HrV0VL = HritzV0toVL{3};
HrV0P0 = HritzV0toP0{3};
HrPLVL = HritzPLtoVL{3};
HrPLP0 = HritzPLtoP0{3};
%%
w_end = 2;

% Vi0/ViL
h4 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,1)),w,abs(HrV0VL(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,1)),w,angle(HrV0VL(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h4,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iVLi16modes','-r600')
% Vi0/VaL
h5 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,2)),w,abs(HrV0VL(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,2)),w,angle(HrV0VL(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h5,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iVLa16modes','-r600')
% Vi0/VpL
h6 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,3)),w,abs(HrV0VL(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,3)),w,angle(HrV0VL(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h6,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iVLp16modes','-r600')
%%
% Vi0/Pi0
h7 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,1)),w,abs(HrV0P0(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,1)),w,angle(HrV0P0(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h7,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iP0i16modes','-r600')
% Vi0/Pa0
h8 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,2)),w,abs(HrV0P0(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,2)),w,angle(HrV0P0(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h8,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iP0a16modes','-r600')
% Vi0/Pp0
h9 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,3)),w,abs(HrV0P0(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,3)),w,angle(HrV0P0(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h9,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0iP0p16modes','-r600')
%%
% Va0/ViL
h10 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,4)),w,abs(HrV0VL(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,4)),w,angle(HrV0VL(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h10,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aVLi16modes','-r600')
% Va0/VaL
h11 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,5)),w,abs(HrV0VL(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,5)),w,angle(HrV0VL(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h11,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aVLa16modes','-r600')
% Va0/VpL
h12 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,6)),w,abs(HrV0VL(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,6)),w,angle(HrV0VL(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h12,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aVLp16modes','-r600')
%%
% Va0/Pi0
h13 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,4)),w,abs(HrV0P0(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,4)),w,angle(HrV0P0(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h13,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aP0i16modes','-r600')
% Va0/Pa0
h14 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,5)),w,abs(HrV0P0(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,5)),w,angle(HrV0P0(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h14,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aP0a16modes','-r600')
% Va0/Pp0
h15 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,6)),w,abs(HrV0P0(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,6)),w,angle(HrV0P0(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h15,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0aP0p16modes','-r600')
%%
% Vp0/ViL
h16 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,7)),w,abs(HrV0VL(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,7)),w,angle(HrV0VL(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h16,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pVLi16modes','-r600')
% Vp0/VaL
h17 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,8)),w,abs(HrV0VL(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,8)),w,angle(HrV0VL(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h17,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pVLa16modes','-r600')
% Vp0/VpL
h18 = figure;
subplot(121), plot(w,abs(HiV0VL_plot(:,9)),w,abs(HrV0VL(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0VL_plot(:,9)),w,angle(HrV0VL(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h18,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pVLp16modes','-r600')
%%
% Vp0/Pi0
h19 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,7)),w,abs(HrV0P0(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,7)),w,angle(HrV0P0(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h19,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pP0i16modes','-r600')
% Vp0/Pa0
h20 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,8)),w,abs(HrV0P0(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,8)),w,angle(HrV0P0(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h20,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pP0a16modes','-r600')
% Vp0/Pp0
h21 = figure;
subplot(121), plot(w,abs(HiV0P0_plot(:,9)),w,abs(HrV0P0(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiV0P0_plot(:,9)),w,angle(HrV0P0(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h21,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\V0pP0p16modes','-r600')

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PiL/ViL
h22 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,1)),w,abs(HrPLVL(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,1)),w,angle(HrPLVL(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h22,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiVLi16modes','-r600')
% PiL/VaL
h23 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,2)),w,abs(HrPLVL(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,2)),w,angle(HrPLVL(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h23,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiVLa16modes','-r600')
% PiL/VpL
h24 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,3)),w,abs(HrPLVL(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,3)),w,angle(HrPLVL(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h24,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiVLp16modes','-r600')
%%
% PiL/Pi0
h25 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,1)),w,abs(HrPLP0(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,1)),w,angle(HrPLP0(:,1)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h25,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiP0i16modes','-r600')
% PiL/Pa0
h26 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,2)),w,abs(HrPLP0(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,2)),w,angle(HrPLP0(:,2)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h26,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiP0a16modes','-r600')
% PiL/Pp0
h27 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,3)),w,abs(HrPLP0(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,3)),w,angle(HrPLP0(:,3)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h27,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLiP0p16modes','-r600')
%%
% PaL/ViL
h28 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,4)),w,abs(HrPLVL(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,4)),w,angle(HrPLVL(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h28,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaVLi16modes','-r600')
% PaL/VaL
h29 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,5)),w,abs(HrPLVL(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,5)),w,angle(HrPLVL(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h29,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaVLa16modes','-r600')
% PaL/VpL
h30 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,6)),w,abs(HrPLVL(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,6)),w,angle(HrPLVL(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h30,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaVLp16modes','-r600')
%%
% PaL/Pi0
h31 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,4)),w,abs(HrPLP0(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,4)),w,angle(HrPLP0(:,4)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h31,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaP0i16modes','-r600')
% PaL/Pa0
h32 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,5)),w,abs(HrPLP0(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,5)),w,angle(HrPLP0(:,5)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h32,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaP0a16modes','-r600')
% PaL/Pp0
h33 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,6)),w,abs(HrPLP0(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,6)),w,angle(HrPLP0(:,6)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h33,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLaP0p16modes','-r600')
%%
% PpL/ViL
h34 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,7)),w,abs(HrPLVL(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,7)),w,angle(HrPLVL(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h34,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpVLi16modes','-r600')
% PpL/VaL
h36 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,8)),w,abs(HrPLVL(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,8)),w,angle(HrPLVL(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h36,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpVLa16modes','-r600')
% PpL/VpL
h37 = figure;
subplot(121), plot(w,abs(HiPLVL_plot(:,9)),w,abs(HrPLVL(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLVL_plot(:,9)),w,angle(HrPLVL(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h37,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpVLp16modes','-r600')
%%
% PpL/Pi0
h38 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,7)),w,abs(HrPLP0(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,7)),w,angle(HrPLP0(:,7)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h38,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpP0i16modes','-r600')
% PpL/Pa0
h39 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,8)),w,abs(HrPLP0(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,8)),w,angle(HrPLP0(:,8)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h39,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpP0a16modes','-r600')
% PpL/Pp0
h40 = figure;
subplot(121), plot(w,abs(HiPLP0_plot(:,9)),w,abs(HrPLP0(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('Amplitude')
subplot(122), plot(w,angle(HiPLP0_plot(:,9)),w,angle(HrPLP0(:,9)),'r--')
xlim([dw,w_end]), xlabel('$\omega$ [rad/s]'), ylabel('angle')
legend('PDE','Ritz')
print(h40,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\PLpP0p16modes','-r600')
















% k = 9;% size(numP,1);
%  %Plotting V0/P0
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,abs(HiV0P0_plot(:,n)),w,abs(HritzV0toP0(:,n)),'black-.')
% end
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,angle(HiV0P0_plot(:,n)),w,angle(HritzV0toP0(:,n)),'black-.')
% end
% %% Plotting V0/VL
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,abs(HiV0VL_plot(:,n)),w,abs(HritzV0toVL(:,n)),'black-.')
% end
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,angle(HiV0VL_plot(:,n)),w,angle(HritzV0toVL(:,n)),'black-.')
% end
% %% Plotting PL/P0
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,abs(HiPLP0_plot(:,n)),w,abs(HritzPLtoP0(:,n)),'black-.')
% end
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,angle(HiPLP0_plot(:,n)),w,angle(HritzPLtoP0(:,n)),'black-.')
% end
% %% Plotting PL/VL
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,abs(HiPLVL_plot(:,n)),w,abs(HritzPLtoVL(:,n)),'black-.')
% end
% figure
% for n = 1:k
%     subplot(sqrt(k),sqrt(k),n)
%     plot(w,angle(HiPLVL_plot(:,n)),w,angle(HritzPLtoVL(:,n)),'black-.')
% end