clear all
close all
clc

%% Parameters
% Generating well paramterers
well = gen_well_parameters;
% Simulation depth (height from bottom)
depth = 0;
% Number of modes in Ritz approximation
num_modes = 16;
% Laplace operator vector
dw = 0.000005;
w = (dw:dw:20)';
s = 1j*w;

%% Calculating analytical frequency solution
HiViL = calc_analytical_freq_response(s,[1 0 0 0 0 0]');
HiVaL = calc_analytical_freq_response(s,[0 1 0 0 0 0]');
HiVpL = calc_analytical_freq_response(s,[0 0 1 0 0 0]');
% HiPi0 = calc_analytical_freq_response(s,[0 0 0 1 0 0]');
% HiPa0 = calc_analytical_freq_response(s,[0 0 0 0 1 0]');
% HiPp0 = calc_analytical_freq_response(s,[0 0 0 0 0 1]');
HiV0VL_plot = [HiViL(:,1:3),HiVaL(:,1:3),HiVpL(:,1:3)];
% HiV0P0_plot = [HiPi0(:,1:3),HiPa0(:,1:3),HiPp0(:,1:3)];
% HiPLVL_plot = [HiViL(:,4:6),HiVaL(:,4:6),HiVpL(:,4:6)];
% HiPLP0_plot = [HiPi0(:,4:6),HiPa0(:,4:6),HiPp0(:,4:6)];
%% Plot Config
width = 8;     % Width in inches
height = 9.6;    % Height in inches
alw = 0.75;    % AxesLineWidth
fsz = 8;      % Fontsize
lw = 2;      % LineWidth
msz = 8;       % MarkerSize
% The properties we've been using in the figures
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaultLineLineWidth',lw);   % set the default line width to lw
set(0,'defaultLineMarkerSize',msz); % set the default line marker size to msz
set(0,'defaulttextfontsize',fsz);
set(0,'defaultAxesFontSize',fsz);
% Set the default Size for display
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);
% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize'); close all;
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);
set(0,'defaulttextinterpreter','latex');
%
h1 = figure;
subplot(411),plot(w,abs(HiV0VL_plot(:,9)))
xlim([w(1),15]),title('$\bar V_p$ $(0)/\bar V_p$ $(L)$')
xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
subplot(412),plot(w,abs(HiV0VL_plot(:,9)))
xlim([w(1),15]),ylim([0,50])
title('$\bar V_p$ $(0)/\bar V_p$ $(L)$, zoom')
xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
subplot(4,1,[3,4]),plot(w,abs(HiV0VL_plot(:,1)))
xlim([w(1),15]),title('$\bar V_i$ $(0)/\bar V_i$ $(L)$')
xlabel('$\omega$[rad/s]'),ylabel('Amplitude')
print(h1,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\spikes','-r600')


height = 4.5;    % Height in inches
defpos = get(0,'defaultFigurePosition');
set(0,'defaultFigurePosition', [defpos(1) defpos(2) width*100, height*100]);
% Set the defaults for saving/printing to a file
set(0,'defaultFigureInvertHardcopy','on'); % This is the default anyway
set(0,'defaultFigurePaperUnits','inches'); % This is the default anyway
defsize = get(gcf, 'PaperSize'); close all;
left = (defsize(1)- width)/2;
bottom = (defsize(2)- height)/2;
defsize = [left, bottom, width, height];
set(0, 'defaultFigurePaperPosition', defsize);

h1 = figure;
subplot(211),plot(w,angle(HiV0VL_plot(:,9)))
xlim([w(1),15]),title('$\bar V_p$ $(0)/\bar V_p$ $(L)$')
xlabel('$\omega$[rad/s]'),ylabel('Phase')
subplot(212),plot(w,angle(HiV0VL_plot(:,1)))
xlim([w(1),15]),title('$\bar V_i$ $(0)/\bar V_i$ $(L)$')
xlabel('$\omega$[rad/s]'),ylabel('Phase')
print(h1,'-dpng','C:\Users\andedah\Dropbox\master\thesis\fig\spikes_phase','-r600')







