clear all
% close all
clc

%% Parameters
% Generating well paramterers
well = gen_well_parameters;
% Simulation depth (height from bottom)
depth = 0;
% Number of modes in Ritz approximation
num_modes = 2*32;
% Finding alpha and gamma for generation of rational approximation
num_freqs = 300;    % Number of sample frequencies to find rational approx
% Weight parameters for weighted inner product, exp(-sigma*t)
sigmaP = 0;       
sigmaV = 0.0;
gamma_func = @(alpha,sigma) (sigma+2*alpha); % Function to find gamma
[gammaV0P0, alphaV0P0] = find_alpha_and_gamma(sigmaP,@sample_ritz_V0toP0,num_modes,depth,num_freqs,gamma_func);
[gammaV0VL, alphaV0VL] = find_alpha_and_gamma(sigmaV,@sample_ritz_V0toVL,num_modes,depth,num_freqs,gamma_func);
[gammaPLP0, alphaPLP0] = find_alpha_and_gamma(sigmaP,@sample_ritz_PLtoP0,num_modes,depth,num_freqs,gamma_func);
[gammaPLVL, alphaPLVL] = find_alpha_and_gamma(sigmaV,@sample_ritz_PLtoVL,num_modes,depth,num_freqs,gamma_func);

[gammaV0VL_test, alphaV0VL_test] = find_alpha_and_gamma(sigmaP,@sample_Vi0ViL,num_modes,depth,num_freqs,gamma_func);
% Order of rational transfer functions
rP = 30;
rV = 20;
% Laplace operator vector
dw = 0.01;
w = (dw:dw:5)';
s = 1j*w;
%% Approximating rational transfer functions
[numV0P0, denV0P0] = gen_rational_tf(num_freqs,alphaV0P0,gammaV0P0,rP,@sample_ritz_V0toP0,num_modes,depth);
[numV0VL, denV0VL] = gen_rational_tf(num_freqs,alphaV0VL,gammaV0VL,rV,@sample_ritz_V0toVL,num_modes,depth);
[numPLP0, denPLP0] = gen_rational_tf(num_freqs,alphaPLP0,gammaPLP0,rP,@sample_ritz_PLtoP0,num_modes,depth);
[numPLVL, denPLVL] = gen_rational_tf(num_freqs,alphaPLVL,gammaPLVL,rV,@sample_ritz_PLtoVL,num_modes,depth);
% rat_tf = calc_rational_tf_modes(@sample_rn_P0,depth,num_modes,num_freqs,sigmaP,rP,gamma_func);
%%
[num_test, den_test] = gen_rational_tf(num_freqs,alphaV0VL_test,gammaV0VL_test,rP,@sample_Vi0ViL,num_modes,depth);
%% Calculating rational transfer functions
% rat_freq_resp_part = zeros(length(s),9);
% for mode=1:num_modes
%     rat_freq_resp_part = rat_freq_resp_part + calc_rational_freq_response(rat_tf(mode).num,rat_tf(mode).den,s);
% end
% sys = gen_transmission_line_freq_dependant_parameters(s);
% Y = sys.Y;
% L = sys.L;
% for k = 1:length(s)
%     temp = diag(diag(Y{k}));
%     rat_freq_resp_part(k,:) = -L*[temp(1,:),temp(2,:),temp(3,:)] + rat_freq_resp_part(k,:);
% end
% HrP = rat_freq_resp_part;

HratV0P0 = calc_rational_freq_response(numV0P0,denV0P0,s);
HratV0VL = calc_rational_freq_response(numV0VL,denV0VL,s);
HratPLP0 = calc_rational_freq_response(numPLP0,denPLP0,s);
HratPLVL = calc_rational_freq_response(numPLVL,denPLVL,s);
%%
H_test = calc_rational_freq_response(num_test,den_test,s);

%% Calculating analytical frequency solution
HiViL = calc_analytical_freq_response(s,[1 0 0 0 0 0]');
HiVaL = calc_analytical_freq_response(s,[0 1 0 0 0 0]');
HiVpL = calc_analytical_freq_response(s,[0 0 1 0 0 0]');
HiPi0 = calc_analytical_freq_response(s,[0 0 0 1 0 0]');
HiPa0 = calc_analytical_freq_response(s,[0 0 0 0 1 0]');
HiPp0 = calc_analytical_freq_response(s,[0 0 0 0 0 1]');
HiV0VL_plot = [HiViL(:,1:3),HiVaL(:,1:3),HiVpL(:,1:3)];
HiV0P0_plot = [HiPi0(:,1:3),HiPa0(:,1:3),HiPp0(:,1:3)];
HiPLVL_plot = [HiViL(:,4:6),HiVaL(:,4:6),HiVpL(:,4:6)];
HiPLP0_plot = [HiPi0(:,4:6),HiPa0(:,4:6),HiPp0(:,4:6)];
%% Calculating irrational Ritz
HritzV0toVL = sample_ritz_V0toVL(s,num_modes,depth);
HritzV0toP0 = sample_ritz_V0toP0(s,num_modes,depth);
HritzPLtoVL = sample_ritz_PLtoVL(s,num_modes,depth);
HritzPLtoP0 = sample_ritz_PLtoP0(s,num_modes,depth);

k = 9;% size(numP,1);
%% Plotting V0/P0
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,abs(HiV0P0_plot(:,n)),w,abs(HritzV0toP0(:,n)),'black-.',w,abs(HratV0P0(:,n)),'r--')
end
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,phase(HiV0P0_plot(:,n)),w,phase(HritzV0toP0(:,n)),'black-.',w,phase(HratV0P0(:,n)),'r--')
end
%% Plotting V0/VL
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    if n == 1
        plot(w,abs(HiV0VL_plot(:,n)),w,abs(H_test))
    else
        plot(w,abs(HiV0VL_plot(:,n)),w,abs(HritzV0toVL(:,n)),'black-.',w,abs(HratV0VL(:,n)),'r--')
    end
end
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    if n == 1
        plot(w,phase(HiV0VL_plot(:,n)),w,phase(H_test))
    else
        plot(w,phase(HiV0VL_plot(:,n)),w,phase(HritzV0toVL(:,n)),'black-.',w,phase(HratV0VL(:,n)),'r--')
    end
end
%% Plotting PL/P0
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,abs(HiPLP0_plot(:,n)),w,abs(HritzPLtoP0(:,n)),'black-.',w,abs(HratPLP0(:,n)),'r--')
end
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,phase(HiPLP0_plot(:,n)),w,phase(HritzPLtoP0(:,n)),'black-.',w,phase(HratPLP0(:,n)),'r--')
end
%% Plotting PL/VL
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,abs(HiPLVL_plot(:,n)),w,abs(HritzPLtoVL(:,n)),'black-.',w,abs(HratPLVL(:,n)),'r--')
end
figure
for n = 1:k
    subplot(sqrt(k),sqrt(k),n)
    plot(w,phase(HiPLVL_plot(:,n)),w,phase(HritzPLtoVL(:,n)),'black-.',w,phase(HratPLVL(:,n)),'r--')
end