function [num, den] = laguerre_gram(q_hat, num_frqs, alpha, gamma, r)
    % Constructing the matrix psi, and the vectors a and b
    psi = zeros(r);
    b = zeros(r,1);
    for eta = 1:size(q_hat,2)
        psi_eta_0 = zeros(r+1);
        for i = 0:r
            psi_eta_0(1,i+1) = 0;
            for n = 0:(num_frqs-i-1)
                psi_eta_0(1,i+1) = psi_eta_0(1,i+1) + q_hat(n+1,eta)*q_hat(n+i+1,eta);
            end
        end
        for i = 1:(r-1)
            for j =i:r
                psi_eta_0(i+1,j+1) = psi_eta_0(i,j) - q_hat(i,eta)*q_hat(j,eta);
            end
        end
        psi_eta = psi_eta_0(1:r,1:r);
        psi_eta = psi_eta + psi_eta'.*(1-eye(r));
        b_eta = psi_eta_0(1:r,r+1);
        
        psi = psi + psi_eta;
        b = b + b_eta;
    end
    a = -psi\b;
    
    % Constructing polynomial
    a(r+1) = 1;         % Trick to ease computation time 
    
    % Generating denominator
    den = zeros(r+1,1);
    for i = 0:r
        den = den + a(i+1)*conv( poly(-alpha*ones(i,1)), ...
                                 poly((gamma-alpha)*ones(r-i,1)) )';
    end
    
    
    % Generating numerator
    num = zeros(size(q_hat,2),r);
    for eta = 1:size(q_hat,2)
        num_eta = zeros(r,1);
        for i = 1:r
            temp = zeros(r,1);
            for j = 0:(i-1)
                temp = temp + q_hat(j+1,eta)*conv( poly(-alpha*ones(i-j-1,1)),...
                                                   poly((gamma-alpha)*ones(r-i+j,1)) ).';
            end
            num_eta = num_eta + a(i+1)*temp;
        end
        num_eta = sqrt(gamma)*num_eta;
        
        num(eta, :) = num_eta'./den(1);
    end    
    den = den'./den(1);
end

